=======
History
=======

0.1.5 (2018-03-05)
------------------
* Adds template filter to create relative dates
* Adds multiply_last_column template filter to add an extra column which multiplies the last string on each line with a custom factor
* Adds percentage_column template filter to add an extra column which shows the percentage of the last string in a line in comparision to the buttom right value of the output 
* Preserves whitespace in double quotes for check_output command 
* Shows report listing in alphabetic order


0.1.4 (2017-12-15)
------------------

* Adds first template (german invoice)
* Adds exception catching for template rendering and hledger commands

0.1.3 (2017-12-15)
------------------

* Adds templating and some initial documenation. 

0.1.2 (2017-12-03)
------------------

* First release on PyPI.
